package cn.com.infosec.asn1.x509;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import java.math.BigInteger;
import java.util.Enumeration;

public class RSAPublicKeyStructure extends ASN1Encodable {
   private BigInteger modulus;
   private BigInteger publicExponent;

   public static RSAPublicKeyStructure getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(ASN1Sequence.getInstance(obj, explicit));
   }

   public static RSAPublicKeyStructure getInstance(Object obj) {
      if (obj != null && !(obj instanceof RSAPublicKeyStructure)) {
         if (obj instanceof ASN1Sequence) {
            return new RSAPublicKeyStructure((ASN1Sequence)obj);
         } else {
            throw new IllegalArgumentException("Invalid RSAPublicKeyStructure: " + obj.getClass().getName());
         }
      } else {
         return (RSAPublicKeyStructure)obj;
      }
   }

   public RSAPublicKeyStructure(BigInteger modulus, BigInteger publicExponent) {
      this.modulus = modulus;
      this.publicExponent = publicExponent;
   }

   public RSAPublicKeyStructure(ASN1Sequence seq) {
      if (seq.size() == 2) {
         RSAPublicKeyStructure var10000 = this;
         Enumeration var2;
         this.modulus = DERInteger.getInstance((var2 = seq.getObjects()).nextElement()).getPositiveValue();
         var10000.publicExponent = DERInteger.getInstance(var2.nextElement()).getPositiveValue();
      } else {
         throw new IllegalArgumentException("Bad sequence size: " + seq.size());
      }
   }

   public BigInteger getModulus() {
      return this.modulus;
   }

   public BigInteger getPublicExponent() {
      return this.publicExponent;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10000 = var1 = new ASN1EncodableVector;
      var10000.<init>();
      var10000.add(new DERInteger(this.getModulus()));
      var10000.add(new DERInteger(this.getPublicExponent()));
      return new DERSequence(var1);
   }
}
